@@ -227,12 +227,10 @@ void Content::clear()
     d->body.clear();
 }
 
-void Content::clearContents(bool del)
+void Content::clearContents()
 {
     Q_D(Content);
-    if (del) {
-        qDeleteAll(d->multipartContents);
-    }
+    qDeleteAll(d->multipartContents);
     d->multipartContents.clear();
     d->clearBodyMessage();
 }
@@ -321,7 +319,7 @@ QByteArray Content::encodedBody() const
     return e;
 }
 
-QByteArray Content::decodedContent() const
+QByteArray Content::decodedBody() const
 {
     QByteArray ret;
     const Headers::ContentTransferEncoding *ec = contentTransferEncoding();
@@ -372,6 +370,11 @@ QByteArray Content::decodedContent() const
     return ret;
 }
 
+QByteArray Content::decodedContent() const
+{
+    return decodedBody();
+}
+
 QString Content::decodedText(DecodedTextTrimOption trimOption) const
 {
     if (!d_ptr->decodeText(this)) {   //this is not a text content !!
@@ -554,7 +557,7 @@ void Content::changeEncoding(Headers::contentEncoding e)
     } else {
         // This is non-textual content.  Re-encode it.
         if (e == Headers::CEbase64) {
-            KCodecs::base64Encode(decodedContent(), d_ptr->body, true);
+            KCodecs::base64Encode(decodedBody(), d_ptr->body, true);
             enc->setEncoding(e);
             d_ptr->m_decoded = false;
         } else {
@@ -672,8 +675,9 @@ bool ContentPrivate::decodeText(const Content *q)
 {
     const Headers::ContentTransferEncoding *enc = q->contentTransferEncoding();
 
-    if (const auto ct = q->contentType(); ct && !ct->isText()) {
-        return false; //non textual data cannot be decoded here => use decodedContent() instead
+    if (const auto ct = q->contentType(); ct && (!ct->isText() || ct->isSubtype("pgp"))) {
+        // content of type text/pgp might be a binary blob of encrypted text; it must not be decoded as text
+        return false; //non textual data cannot be decoded here => use decodedBody() instead
     }
     if (m_decoded) {
         return true; //nothing to do
@@ -717,7 +721,7 @@ Content *KMime::Content::content(const ContentIndex &index) const
     }
 }
 
-ContentIndex KMime::Content::indexForContent(Content *content) const
+ContentIndex KMime::Content::indexForContent(const Content *content) const
 {
     const auto i = d_ptr->contents().indexOf(content);
     if (i >= 0) {
@@ -861,7 +865,8 @@ bool ContentPrivate::parseUuencoded(Content *q)
         // This seems to be only a part of the message, so we treat it as "message/partial".
         ct->setMimeType("message/partial");
         //ct->setId( uniqueString() ); not needed yet
-        ct->setPartialParams(uup.partialCount(), uup.partialNumber());
+        ct->setPartialCount(uup.partialCount());
+        ct->setPartialNumber(uup.partialNumber());
         q->contentTransferEncoding()->setEncoding(Headers::CE7Bit);
     } else {
         // This is a complete message, so treat it as "multipart/mixed".
@@ -886,7 +891,7 @@ bool ContentPrivate::parseUuencoded(Content *q)
         // Now add each of the binary parts as sub-Contents.
         for (int i = 0; i < uup.binaryParts().count(); ++i) {
             auto c = new Content(q);
-            c->contentType()->setMimeType(uup.mimeTypes().at(i));
+            c->contentType()->setMimeType(uup.mimeTypes().at(i) == "message/rfc822" ? "text/plain" : uup.mimeTypes().at(i));
             c->contentType()->setName(QLatin1StringView(uup.filenames().at(i)));
             c->contentTransferEncoding()->setEncoding(Headers::CEuuenc);
             c->contentDisposition()->setDisposition(Headers::CDattachment);
@@ -916,7 +921,8 @@ bool ContentPrivate::parseYenc(Content *q)
         // Assume there is exactly one decoded part.  Treat this as "message/partial".
         ct->setMimeType("message/partial");
         //ct->setId( uniqueString() ); not needed yet
-        ct->setPartialParams(yenc.partialCount(), yenc.partialNumber());
+        ct->setPartialCount(yenc.partialCount());
+        ct->setPartialNumber(yenc.partialNumber());
         q->contentTransferEncoding()->setEncoding(Headers::CEbinary);
         q->changeEncoding(Headers::CEbase64);   // Convert to base64.
     } else {
