@@ -371,11 +371,8 @@ bool MailboxList::parse(const char *&scursor, const char *const send,
 
     // extract the mailboxes and complain if there are groups:
     for (const auto &it : std::as_const(maybeAddressList)) {
-        if (!(it).displayName.isEmpty()) {
-            KMIME_WARN << "mailbox groups in header disallowing them! Name: \""
-                       << (it).displayName << "\""
-                       << Qt::endl
-                          ;
+        if (!(it).displayName().isEmpty()) {
+            KMIME_WARN << "mailbox groups in header disallowing them! Name:" << (it).displayName();
         }
         d->mailboxList += (it).mailboxList;
     }
@@ -967,10 +964,10 @@ QList<QByteArray> Ident::identifiers() const {
     return rv;
 }
 
-void Ident::fromIdent(const Ident* ident)
+void Ident::fromIdent(const Ident &ident)
 {
-    d_func()->encCS = ident->d_func()->encCS;
-    d_func()->msgIdList = ident->d_func()->msgIdList;
+    d_func()->encCS = ident.d_func()->encCS;
+    d_func()->msgIdList = ident.d_func()->msgIdList;
 }
 
 void Ident::appendIdentifier(const QByteArray &id)
@@ -1730,6 +1727,11 @@ int ContentType::partialNumber() const {
     }
 }
 
+void ContentType::setPartialNumber(int number)
+{
+    setParameter(QByteArrayLiteral("number"), QString::number(number));
+}
+
 int ContentType::partialCount() const {
     QByteArray p = parameter("total").toLatin1();
     if (!p.isEmpty()) {
@@ -1739,8 +1741,8 @@ int ContentType::partialCount() const {
     }
 }
 
-void ContentType::setPartialParams(int total, int number) {
-    setParameter(QByteArrayLiteral("number"), QString::number(number));
+void ContentType::setPartialCount(int total)
+{
     setParameter(QByteArrayLiteral("total"), QString::number(total));
 }
 
